'use strict';

Object.defineProperty(exports, '__esModule', {
  value: true
});
function createSafeJsonParser(_ref) {
  let {
    errorLabel
  } = _ref;
  return function safeJsonParser(line) {
    try {
      return JSON.parse(line);
    } catch (err) {
      const errorPosition = line.lastIndexOf('{"error":');
      if (errorPosition === -1) {
        err.message = "".concat(err.message, " (").concat(line, ")");
        throw err;
      }
      const errorJson = line.slice(errorPosition);
      const errorLine = JSON.parse(errorJson);
      const error = errorLine && errorLine.error;
      if (error && error.description) {
        throw new Error("".concat(errorLabel, ": ").concat(error.description, "\n\n").concat(errorJson, "\n"));
      }
      throw err;
    }
  };
}
exports.createSafeJsonParser = createSafeJsonParser;
//# sourceMappingURL=createSafeJsonParser.js.map
